aboutsummaryrefslogtreecommitdiff
path: root/gdb/cli/cli-setshow.h
diff options
context:
space:
mode:
Diffstat (limited to 'gdb/cli/cli-setshow.h')
-rw-r--r--gdb/cli/cli-setshow.h20
1 files changed, 9 insertions, 11 deletions
diff --git a/gdb/cli/cli-setshow.h b/gdb/cli/cli-setshow.h
index 78573c0..bc70ea6 100644
--- a/gdb/cli/cli-setshow.h
+++ b/gdb/cli/cli-setshow.h
@@ -29,21 +29,19 @@ extern int parse_cli_boolean_value (const char *arg);
past a successfully parsed value. */
extern int parse_cli_boolean_value (const char **arg);
-/* Parse ARG, an option to a var_uinteger or var_zuinteger variable.
- Either returns the parsed value on success or throws an error. If
- EXPRESSION is true, *ARG is parsed as an expression; otherwise, it
- is parsed with get_ulongest. It's not possible to parse the
+/* Parse ARG, an option to a var_uinteger, var_integer or var_pinteger
+ variable. Return the parsed value on success or throw an error. If
+ EXTRA_LITERALS is non-null, then interpret those literals accordingly.
+ If EXPRESSION is true, *ARG is parsed as an expression; otherwise,
+ it is parsed with get_ulongest. It's not possible to parse the
integer as an expression when there may be valid input after the
integer, such as when parsing command options. E.g., "print
-elements NUMBER -obj --". In such case, parsing as an expression
would parse "-obj --" as part of the expression as well. */
-extern unsigned int parse_cli_var_uinteger (var_types var_type,
- const char **arg,
- bool expression);
-
-/* Like parse_cli_var_uinteger, for var_zuinteger_unlimited. */
-extern int parse_cli_var_zuinteger_unlimited (const char **arg,
- bool expression);
+extern LONGEST parse_cli_var_integer (var_types var_type,
+ const literal_def *extra_literals,
+ const char **arg,
+ bool expression);
/* Parse ARG, an option to a var_enum variable. ENUM is a
null-terminated array of possible values. Either returns the parsed